# yaclipy-tools

This is a collection of wrappers around common system tools that works well with [yaclipy](https://pypi.org/project/yaclipy)

## Tools

* openssl
* shasum
* md5
* gpg
* nginx
* grep
* gpg
* curl
* ffmpeg
* git


The set of tools can easily be extended by subclassing SysTool


[![PyPI - Version](https://img.shields.io/pypi/v/yaclipy-tools.svg)](https://pypi.org/project/yaclipy-tools)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/yaclipy-tools.svg)](https://pypi.org/project/yaclipy-tools)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install yaclipy-tools
```

## License

`yaclipy-tools` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
